/**
* @license Copyright (c) Microsoft Corporation.  All rights reserved.
*/
/// <reference path="../../../../TypeDefinitions/mscrm.d.ts" />
/// <reference path="CommonReferences.ts" />
/// <reference path="../../../../../references/external/TypeDefinitions/jquery.d.ts" />
/// <reference path="../../../../../references/external/TypeDefinitions/lib.es6.d.ts"/> 
/**
* @license Copyright (c) Microsoft Corporation.  All rights reserved.
*/
/// <reference path="privatereferences.ts"/>
var MscrmControls;
(function (MscrmControls) {
    var USD;
    (function (USD) {
        var Controls;
        (function (Controls) {
            'use strict';
            var AppSelectorControl = (function () {
                /**
                 * Constructor.
                 */
                function AppSelectorControl() {
                    this._context = null;
                }
                /**
                 * This function should be used for any initial setup necessary for your control.
                 * @params context The "Input Bag" containing the parameters and other control metadata.
                 * @params notifyOutputchanged The method for this control to notify the framework that it has new outputs
                 * @params state The user state for this control set from setState in the last session
                 * @params container The div element to draw this control in
                 */
                AppSelectorControl.prototype.init = function (context, notifyOutputChanged, state, container) {
                    // custom code goes here
                    this._context = context;
                    this._notifyOutputChanged = notifyOutputChanged || (function () { });
                    this._appList = [];
                    this._currentSelectedApp = this.isNullOrUndefined(this._context.parameters.appName.raw) ? "" : this._context.parameters.appName.raw;
                    this.getAllApps();
                };
                AppSelectorControl.prototype.getAllApps = function () {
                    var _this = this;
                    //Fetching only required fields and filtering only UCI apps
                    this._context.webAPI.retrieveMultipleRecords("appmodule", "?$select=name,uniquename,appmoduleid&$filter=clienttype eq 4").then(function (data) {
                        for (var _i = 0, _a = data.entities; _i < _a.length; _i++) {
                            var app = _a[_i];
                            //Filtering out USD Admin app
                            if (app.uniquename != "msdyusd_USDAdminSettings") {
                                _this._appList.push({ AppId: app.appmoduleid, AppName: app.name, AppUniqueName: app.uniquename });
                            }
                        }
                        _this._context.utils.requestRender();
                    }, function (error) {
                        var errorDialogOptions = {
                            message: _this._context.resources.getString("WebApiRequestFailed")
                        };
                        Xrm.Navigation.openErrorDialog(errorDialogOptions);
                        _this._context.reporting.reportFailure("USD.AppSelectorControl.getAllApps", Error(errorDialogOptions.message), null, [
                            { name: "FunctionName", value: "AppSelectorControl.getAllApps" },
                            { name: "Error", value: error.message }
                        ]);
                    });
                };
                /**
                 * This function will recieve an "Input Bag" containing the values currently assigned to the parameters in your manifest
                 * It will send down the latest values (static or dynamic) that are assigned as defined by the manifest & customization experience
                 * as well as resource, client, and theming info (see mscrm.d.ts)
                 * @params context The "Input Bag" as described above
                 */
                AppSelectorControl.prototype.updateView = function (context) {
                    //return null;
                    var _this = this;
                    if (this._appList.length == 0) {
                        return null;
                    }
                    var autoCompleteProps = {
                        "parameters": {
                            "source": {
                                Value: "Option Set",
                                Type: "OptionSet",
                                Primary: false,
                                Static: false,
                                Attributes: {
                                    "Options": this._createAppsOptionsList()
                                },
                                Usage: 3 //PropertyUsage.FalseBound
                            },
                            "value": {
                                Value: this._currentSelectedApp,
                                Type: "SingleLine.Text",
                                Primary: true,
                                Attributes: {
                                    "MaxLength": "500",
                                    "Behavior": 1
                                },
                                Static: true,
                                Usage: 3,
                                Callback: function (selectedApp) { _this.setAppValue(selectedApp); }
                            },
                            "dataSourceSwitch": {
                                Type: "GroupDefinition",
                                Value: "OptionSetGroup"
                            }
                        },
                    };
                    return this._context.factory.createComponent("MscrmControls.AutoComplete.AutoCompleteControl", "AppSelector_AutoCompleteControl", autoCompleteProps);
                };
                /**
                 * This function will return an "Output Bag" to the Crm Infrastructure
                 * The ouputs will contain a value for each property marked as "input-output"/"bound" in your manifest
                 * i.e. if your manifest has a property "value" that is an "input-output", and you want to set that to the local variable "myvalue" you should return:
                 * {
                 *		value: myvalue
                 * };
                 * @returns The "Output Bag" containing values to pass to the infrastructure
                 */
                AppSelectorControl.prototype.getOutputs = function () {
                    // custom code goes here - remove the line below and return the correct output
                    var output = {
                        appName: this._currentSelectedApp
                    };
                    return output;
                };
                /**
                 * This function will be called when the control is destroyed
                 * It should be used for cleanup and releasing any memory the control is using
                 */
                AppSelectorControl.prototype.destroy = function () {
                };
                AppSelectorControl.prototype.setAppValue = function (selectedAppValue) {
                    this._currentSelectedApp = selectedAppValue;
                    var selectedAppIdAttribute;
                    if (Xrm && Xrm.Page && (selectedAppIdAttribute = Xrm.Page.getAttribute("msdyusd_uciappid"))) {
                        var filteredApps = this._appList.filter(function (app) { return app.AppName == selectedAppValue; });
                        if (filteredApps.length > 0) {
                            selectedAppIdAttribute.setValue(filteredApps[0].AppId);
                        }
                    }
                    this._notifyOutputChanged();
                };
                AppSelectorControl.prototype._createAppsOptionsList = function () {
                    var defaultList = [];
                    var appList = [];
                    if (this._appList.length == 0) {
                        return defaultList;
                    }
                    for (var i = 0; i < this._appList.length; i++) {
                        var currentApp = this._appList[i];
                        appList.push({
                            text: currentApp.AppName,
                            Label: currentApp.AppName,
                            id: i + 1,
                            value: currentApp.AppUniqueName
                        });
                    }
                    return appList;
                };
                /**
                 * This method checks if object is null or undefined.
                 * @param object object to be checked
                 */
                AppSelectorControl.prototype.isNullOrUndefined = function (object) {
                    return this._context.utils.isNullOrUndefined(object);
                };
                return AppSelectorControl;
            }());
            Controls.AppSelectorControl = AppSelectorControl;
        })(Controls = USD.Controls || (USD.Controls = {}));
    })(USD = MscrmControls.USD || (MscrmControls.USD = {}));
})(MscrmControls || (MscrmControls = {}));
/**
* @license Copyright (c) Microsoft Corporation. All rights reserved.
*/
/// <reference path="inputsoutputs.g.ts" />
/// <reference path="AppSelectorControl.ts" />
//# sourceMappingURL=AppSelectorControl.js.map