/**
* @license Copyright (c) Microsoft Corporation.  All rights reserved.
*/
/// <reference path="../../../../TypeDefinitions/mscrm.d.ts" />
/// <reference path="CommonReferences.ts" />
/// <reference path="../../../../../references/external/TypeDefinitions/jquery.d.ts" />
/// <reference path="../../../../../references/external/TypeDefinitions/lib.es6.d.ts"/> 
/**
* @license Copyright (c) Microsoft Corporation.  All rights reserved.
*/
/// <reference path="privatereferences.ts"/>
var MscrmControls;
(function (MscrmControls) {
    var USD;
    (function (USD) {
        var Controls;
        (function (Controls) {
            'use strict';
            var FILE_LABEL_ID = "file_label";
            var ANNOTATION_ENTITY_NAME = "annotation";
            var RequestState;
            (function (RequestState) {
                RequestState[RequestState["None"] = 0] = "None";
                RequestState[RequestState["Pending"] = 1] = "Pending";
                RequestState[RequestState["Success"] = 2] = "Success";
                RequestState[RequestState["Failure"] = 3] = "Failure";
            })(RequestState || (RequestState = {}));
            var KeyCode;
            (function (KeyCode) {
                KeyCode[KeyCode["Enter"] = 13] = "Enter";
                KeyCode[KeyCode["Space"] = 32] = "Space";
            })(KeyCode || (KeyCode = {}));
            var FilePicker = (function () {
                /**
                 * Empty constructor.
                 */
                function FilePicker() {
                }
                /**
                 * This function should be used for any initial setup necessary for your control.
                 * @params context The "Input Bag" containing the parameters and other control metadata.
                 * @params notifyOutputchanged The method for this control to notify the framework that it has new outputs
                 * @params state The user state for this control set from setState in the last session
                 * @params container The div element to draw this control in
                 */
                FilePicker.prototype.init = function (context, notifyOutputChanged, state) {
                    // custom code goes here
                    this._fileSelectedHandler = this.fileSelected.bind(this);
                    this._context = context;
                    this._notifyOutputChanged = notifyOutputChanged || (function () { });
                    // initializing the utilities
                    this.attachmentDownloadUtility = new Controls.AttachmentDownloadUtility(context);
                    this.fileIconUtility = new Controls.CrmIconSymbolMapping();
                    this.stylingInfo = new Controls.AttachmentControlStyles(context);
                    //initialize the resx enteries
                    this.clickToOpenTxt = this._context.resources.getString("ToolTip_Attachment_Download");
                    this.browseFileTxt = this._context.resources.getString("File_Attachment_Label_Choose");
                    this.deleteTooltip = this._context.resources.getString("File_Attachment_Delete_Tooltip");
                    this.uploadFailureTxt = this._context.resources.getString("File_UploadFailure");
                    this.deletionFailureTxt = this._context.resources.getString("File_DeletionFailure");
                    this.invalidFileDialogTitle = this._context.resources.getString("InvalidFileDialogAlertTitle");
                    this.invalidFileDialogTxt = this._context.resources.getString("InvalidFileDialogAlertText");
                    this.uploadButtonTxt = this._context.resources.getString("UploadButtonText");
                    this.loadingTxt = this._context.resources.getString("LoadingText");
                    this.errorResponseTxt = this._context.resources.getString("ErrorResponse");
                    this.createModeTxt = this._context.resources.getString("CreateModeText");
                    this.confirmDeleteTxt = this._context.resources.getString("Confirm_Delete_Text");
                    this.confirmDeleteTitle = this._context.resources.getString("Confirm_Delete_Title");
                    this.continueDeletionButtonTxt = this._context.resources.getString("Delete");
                    //Initializing only related entity name and collection name since they are static properties.
                    // Other properties are dynamic
                    this.relatedEntityName = this._context.parameters.regardingEntityName.raw;
                    this.relatedEntityCollectionName = this._context.parameters.regardingEntityCollectionName.raw;
                    this.reqState = RequestState.None;
                    this.annotationId = "";
                    var _this = this;
                    // DO retrieve for edit form
                    if (Xrm.Page.ui.getFormType() == 2) {
                        this.reqState = RequestState.Pending;
                        if (this._context.parameters.regardingObjectId != null && this._context.parameters.regardingObjectId.formatted != "") {
                            // Third parameter is 1 since we always wanted to get a single record after sorting by createdon. Following webclient behavior
                            // if there are no annotations related to entity, then this will return 0 records.
                            Xrm.WebApi.retrieveMultipleRecords(ANNOTATION_ENTITY_NAME, "?$filter=_objectid_value%20eq%20" + this._context.parameters.regardingObjectId.formatted + "&$orderby=createdon%20desc", 1).then(function success(result) {
                                _this.reqState = RequestState.Success;
                                console.log("Retrieved annotation entities related to objectid " + _this._context.parameters.regardingObjectId.formatted);
                                console.log("No of entities retrieved " + result.entities.length); // Length will be either 0 or 1.
                                if (result.entities.length == 1) {
                                    _this.annotationId = result.entities[0].annotationid;
                                    _this.filename = result.entities[0].filename;
                                    _this.content = result.entities[0].documentbody;
                                    _this.filetype = result.entities[0].mimetype;
                                    _this.filesize = result.entities[0].filesize;
                                }
                                _this._context.utils.requestRender();
                            }, function (error) {
                                _this.reqState = RequestState.Failure;
                                console.log("Error on retrieving related annotations. Error Code: " + error.code + " Error message: " + error.message);
                                _this._context.utils.requestRender();
                            });
                        }
                        else {
                            _this.reqState = RequestState.Failure;
                            _this._context.utils.requestRender();
                        }
                    }
                };
                /**
                 * This function will recieve an "Input Bag" containing the values currently assigned to the parameters in your manifest
                 * It will send down the latest values (static or dynamic) that are assigned as defined by the manifest & customization experience
                 * as well as resource, client, and theming info (see mscrm.d.ts)
                 * @params context The "Input Bag" as described above
                 */
                FilePicker.prototype.updateView = function (context) {
                    // custom code goes here
                    var controls = [];
                    // if it is edit form, there can be three states. 
                    // 1. No attachments related to main entity. Show create file state where user can attach new files.
                    // 2. Attachments are already related to main entity. Show the file name and delete option
                    // 3. Deletion / creation of attachment is kicked in by other methods and control is waiting for web call to get over. Hence show laoding text
                    // if main entity is in create mode, then let them know that attachments can be linked only after the creation of main entity record.
                    if (Xrm.Page.ui.getFormType() == 2) {
                        switch (this.reqState) {
                            case RequestState.None:
                            case RequestState.Success:
                                this.annotationId != "" ? controls.push(this.createFileSelectedHeaderElement()) :
                                    controls.push(this.createFileUploaderElement());
                                return this.createRootContainer(controls, "completePage");
                            case RequestState.Pending:
                                controls.push(this.CreateWaitingStateElement());
                                return this.createRootContainer(controls, "completePage");
                            default:
                                controls.push(this.CreateFailureStateElement());
                                return this.createRootContainer(controls, "completePage");
                        }
                    }
                    else {
                        controls.push(this.CreateCreateModeStateElement());
                        return this.createRootContainer(controls, "completePage");
                    }
                };
                /**
                 * This function will return an "Output Bag" to the Crm Infrastructure
                 * The ouputs will contain a value for each property marked as "input-output"/"bound" in your manifest
                 * i.e. if your manifest has a property "value" that is an "input-output", and you want to set that to the local variable "myvalue" you should return:
                 * {
                 *		value: myvalue
                 * };
                 * @returns The "Output Bag" containing values to pass to the infrastructure
                 */
                FilePicker.prototype.getOutputs = function () {
                    // custom code goes here - remove the line below and return the correct output
                    return null;
                };
                /**
                 * This function will be called when the control is destroyed
                 * It should be used for cleanup and releasing any memory the control is using
                 */
                FilePicker.prototype.destroy = function () {
                };
                /**
                 * Creates the root container for attachment control visualization
                 */
                FilePicker.prototype.createRootContainer = function (controls, containerSuffix) {
                    return this._context.factory.createElement("CONTAINER", {
                        key: "containerWithControls" + containerSuffix,
                        style: {
                            width: '100%',
                            borderColor: '#CFCDCC',
                            borderStyle: 'solid',
                            borderWidth: '1px',
                            padding: '5px 10px'
                        }
                    }, controls);
                };
                /**
                 * Creates the file upload visualization for the attachment
                 */
                FilePicker.prototype.createFileUploaderElement = function () {
                    var _this = this;
                    var props = {
                        id: "file-uploader",
                        key: "file-uploader",
                        accessibilityLabel: this.browseFileTxt,
                        tabIndex: 0,
                        fileSelected: this._fileSelectedHandler,
                        style: {
                            width: '85%'
                        }
                    };
                    var fileInput = this._context.factory.createElement("FILEINPUT", props);
                    var uploadbutton = this._context.factory.createElement("BUTTON", {
                        key: "Upload",
                        id: "Upload",
                        role: "button",
                        style: {
                            color: 'white',
                            width: '15%',
                            justifyContent: 'center',
                            borderColor: '#3B79B7',
                            borderRadius: '2px',
                            background: '#3B79B7',
                            cursor: 'pointer'
                        },
                        tabIndex: 0,
                        onClick: function (e) { return _this.uploadFile(e); },
                        onKeyDown: function (e) { return _this.uploadFile(e); }
                    }, this.uploadButtonTxt);
                    var container = this._context.factory.createElement("CONTAINER", {
                        key: "donebutton",
                        style: {
                            width: '100%',
                        }
                    }, [fileInput, uploadbutton]);
                    return container;
                };
                FilePicker.prototype.CreateWaitingStateElement = function () {
                    var props = {
                        id: "loading",
                        key: "loading",
                        accessibilityLabel: this.loadingTxt,
                        tabIndex: 0,
                    };
                    var waiting = this._context.factory.createElement("LABEL", props, this.loadingTxt);
                    return waiting;
                };
                FilePicker.prototype.CreateFailureStateElement = function () {
                    var props = {
                        id: "Failure",
                        key: "Failure",
                        accessibilityLabel: this.errorResponseTxt,
                        tabIndex: 0,
                    };
                    var failureText = this._context.factory.createElement("LABEL", props, this.errorResponseTxt);
                    return failureText;
                };
                FilePicker.prototype.CreateCreateModeStateElement = function () {
                    var props = {
                        id: "createmodetxt",
                        key: "createmodetxt",
                        accessibilityLabel: this.createModeTxt,
                        tabIndex: 0,
                    };
                    var failureText = this._context.factory.createElement("LABEL", props, this.createModeTxt);
                    return failureText;
                };
                /**
                 * Creates the file Icon visualization for file details for the attachment
                 */
                FilePicker.prototype.createFileIconElement = function () {
                    var imgType = this.fileIconUtility.getFileIcon(this.filename);
                    return this._context.factory.createElement("MICROSOFTICON", {
                        key: "img_FileIcon",
                        id: "img_FileIcon",
                        labelledByElementId: this._context.accessibility.getUniqueId(FILE_LABEL_ID),
                        tabIndex: 0,
                        role: "img",
                        type: imgType,
                        style: this.stylingInfo.getCssStyle(Controls.StyleItemsName.FONTICON),
                        onClick: null
                    });
                };
                FilePicker.prototype.uploadFile = function (event) {
                    if (event.type == "keydown" && !(event.keyCode == KeyCode.Enter || event.keyCode == KeyCode.Space)) {
                        return;
                    }
                    var _this = this;
                    if (this.filename == null || this.filename == "" || this.content == null || this.content == "") {
                        Xrm.Navigation.openAlertDialog({ "title": this.invalidFileDialogTitle, "text": this.invalidFileDialogTxt });
                        return;
                    }
                    this.reqState = RequestState.Pending;
                    var objectIdParameter = "objectid_" + this.relatedEntityName + "@odata.bind";
                    var objectIdParameterValue = "/" + this.relatedEntityCollectionName + "(" + this._context.parameters.regardingObjectId.formatted + ")";
                    var recordValues = {};
                    recordValues["filename"] = this.filename;
                    recordValues["filesize"] = this.filesize;
                    recordValues["mimetype"] = this.filetype;
                    recordValues["documentbody"] = this.content;
                    recordValues["isdocument"] = true;
                    recordValues[objectIdParameter] = objectIdParameterValue;
                    Xrm.WebApi.createRecord(ANNOTATION_ENTITY_NAME, recordValues).then(function success(result) {
                        console.log("Annotation got created. AnnotationId: " + result.id);
                        _this.annotationId = result.id;
                        _this.reqState = RequestState.Success;
                        _this._context.utils.requestRender();
                        // perform operations on record retrieval
                    }, function (error) {
                        console.log("Annotation creation failed. Error code" + error.code + " Error message " + error.message);
                        _this.reqState = RequestState.Failure;
                        _this._context.utils.requestRender();
                        var errorMsg = _this.uploadFailureTxt;
                        if (error.message) {
                            errorMsg = error.message;
                        }
                        Xrm.Navigation.openErrorDialog({ message: errorMsg, errorCode: error.code });
                    });
                    this._context.utils.requestRender(); // for showing Loading
                };
                /**
                 * Creates the close Icon visualization for file details for the attachment
                 */
                FilePicker.prototype.removeFileElement = function () {
                    var _this = this;
                    var imgType = this.fileIconUtility.getCloseIcon();
                    return this._context.factory.createElement("MICROSOFTICON", {
                        key: "img_RemoveIcon",
                        id: "img_RemoveIcon",
                        tabIndex: 0,
                        role: "button",
                        title: this.deleteTooltip,
                        accessibilityLabel: this.deleteTooltip,
                        type: imgType,
                        style: this.stylingInfo.getCssStyle(Controls.StyleItemsName.ACTIONABLE_FONT_ICON),
                        onClick: function (e) { return _this.removeFile(e); },
                        onKeyDown: function (e) { return _this.removeFile(e); }
                    });
                };
                FilePicker.prototype.removeFile = function (event) {
                    if (event.type == "keydown" && !(event.keyCode == KeyCode.Enter || event.keyCode == KeyCode.Space)) {
                        return;
                    }
                    var confirmationStrings = { "text": this.confirmDeleteTxt, "title": this.confirmDeleteTitle, "confirmButtonLabel": this.continueDeletionButtonTxt }; // Instead of OK, we are sending continue. Leaving cancel button text as provided by Xrm.
                    var confirmOptions = { height: 205, width: 450 }; // following webclient
                    var _this = this;
                    Xrm.Navigation.openConfirmDialog(confirmationStrings, confirmOptions).
                        then(function (result) {
                        if (result.confirmed) {
                            Xrm.WebApi.deleteRecord(ANNOTATION_ENTITY_NAME, _this.annotationId).then(function success(result) {
                                console.log("Deletion of annotation succeeded. Delete annotation record: " + _this.annotationId);
                                _this.filename = null;
                                _this.filesize = null;
                                _this.content = null;
                                _this.filetype = null;
                                _this.annotationId = "";
                                _this.reqState = RequestState.Success;
                                _this._context.utils.requestRender();
                            }, function (error) {
                                var errorMsg = _this.deletionFailureTxt;
                                if (error.message) {
                                    errorMsg = error.message;
                                }
                                Xrm.Navigation.openErrorDialog({ message: errorMsg, errorCode: error.code });
                                console.log("Annotation deletion failed. Error code" + error.code + " Error message " + error.message);
                            });
                        }
                    });
                };
                /**
                 * Creates the visualization foafter file upload for the attachment
                 */
                FilePicker.prototype.createFileSelectedHeaderElement = function () {
                    var _this = this;
                    var fileNameAccessibility = this.clickToOpenTxt;
                    //element for file name label
                    var fileLabel = this._context.factory.createElement("HYPERLINK", {
                        id: FILE_LABEL_ID,
                        key: FILE_LABEL_ID,
                        role: "link",
                        tabIndex: 0,
                        title: fileNameAccessibility,
                        accessibilityLabel: this.filename,
                        style: this.stylingInfo.getCssStyle(Controls.StyleItemsName.FILELABEL),
                        onClick: function (e) { return _this.fileDownload(e); },
                        onKeyDown: function (e) { return _this.fileDownload(e); }
                    }, this.filename);
                    return this._context.factory.createElement("CONTAINER", {
                        key: "fileselected_Container",
                        style: this.stylingInfo.getCssStyle(Controls.StyleItemsName.FILECONTAINER)
                    }, [this.createFileIconElement(), fileLabel, this.removeFileElement()]);
                };
                /**
                 * Onclick handler for file name label to initiate its download
                 */
                FilePicker.prototype.fileDownload = function (event) {
                    if (event.type === "keydown" && event.keyCode !== KeyCode.Enter) {
                        return;
                    }
                    else {
                        event.preventDefault();
                        //Encoded file content, file name, file size, mime type and other attributes are saved as part of the entity record to which the control is bound. 
                        //But when trying to downlod the file, by default activitymimeattachment entity is searched for attachment id.
                        //Search needs to be performed on the entity record passed as a parameter via control manifest file. As this is an optional param, search would fallback to activitymimeattachment entity.
                        this.attachmentDownloadUtility.fileDownloadBase(this.annotationId.toString(), ANNOTATION_ENTITY_NAME);
                    }
                };
                /**
                 * Handler to read the file content, name, size, type into class variables
                 */
                FilePicker.prototype.fileSelected = function (file) {
                    var nameList = file.name.toLowerCase().split('.');
                    if ((nameList.length >= 2 && nameList[nameList.length - 1] != "zip") || (nameList.length < 2)) {
                        Xrm.Navigation.openAlertDialog({ "title": this.invalidFileDialogTitle, "text": this.invalidFileDialogTxt });
                        return;
                    }
                    this.content = file.content;
                    this.filename = file.name;
                    this.filesize = file.size,
                        this.filetype = file.mimeType;
                };
                return FilePicker;
            }());
            Controls.FilePicker = FilePicker;
        })(Controls = USD.Controls || (USD.Controls = {}));
    })(USD = MscrmControls.USD || (MscrmControls.USD = {}));
})(MscrmControls || (MscrmControls = {}));
/**
* @license Copyright (c) Microsoft Corporation. All rights reserved.
*/
/// <reference path="inputsoutputs.g.ts" />
/// <reference path="FilePicker.ts" /> 
/// <reference path="privatereferences.ts" />
var MscrmControls;
(function (MscrmControls) {
    var USD;
    (function (USD) {
        var Controls;
        (function (Controls) {
            'use strict';
            Controls.AttachmentFileName = "filename";
            Controls.AttachmentMimeType = "mimetype";
            Controls.OpenFileSaveMode = 2;
            /**
             * Handles fecthing the font  icon type based on the file type
             */
            var CrmIconSymbolMapping = (function () {
                function CrmIconSymbolMapping() {
                }
                /**
                 * Returns the Font Icon Number for file type
                 */
                CrmIconSymbolMapping.prototype.getFileIcon = function (fileName) {
                    var imgType;
                    var fileExtension = fileName.split('.').pop();
                    switch (fileExtension.toUpperCase()) {
                        //HTM
                        case "HTM":
                        case "HTML":
                            imgType = 211;
                            break;
                        //Word
                        case "DOC":
                        case "DOCX":
                            imgType = 146;
                            break;
                        //Excel
                        case "XLS":
                        case "XLSX":
                            imgType = 147;
                            break;
                        //Power Point
                        case "PPT":
                        case "PPTX":
                            imgType = 193;
                            break;
                        //Project
                        case "MPP":
                        case "MPT":
                        case "MPX":
                        case "MPD":
                            imgType = 197;
                            break;
                        //Visio
                        case "VSD":
                        case "VSDX":
                        case "VDX":
                            imgType = 196;
                            break;
                        //PDF
                        case "PDF":
                            imgType = 192;
                            break;
                        //Access
                        case "ACCDA":
                        case "ACCDR":
                        case "ACCDT":
                            imgType = 195;
                            break;
                        //OneNote
                        case "ONE":
                            imgType = 194;
                            break;
                        // Image File Extension Support
                        case "GIF":
                        case "EPS":
                        case "AI":
                        case "TIF":
                        case "PSD":
                        case "JPG":
                        case "PNG":
                        case "RLE":
                        case "BMP":
                        case "TGA":
                        case "PIC":
                            imgType = 210;
                            break;
                        // Video File Extension Support
                        case "MOV":
                        case "MPG":
                        case "AVI":
                        case "WMF":
                        case "RAM":
                        case "QT":
                        case "SND":
                            imgType = 209;
                            break;
                        // Audio File Extension Support
                        case "WAV":
                        case "MP3":
                            imgType = 207;
                            break;
                        // All other File Extensions
                        default:
                            imgType = 43;
                            break;
                    }
                    return imgType;
                };
                /**
                 * Returns the Close Icon Number for file type
                 */
                CrmIconSymbolMapping.prototype.getCloseIcon = function () {
                    return 97;
                };
                return CrmIconSymbolMapping;
            }());
            Controls.CrmIconSymbolMapping = CrmIconSymbolMapping;
            /**
             * Handles attachment downloading from generating toekn to constructing download url to downloading the file
             */
            var AttachmentDownloadUtility = (function () {
                function AttachmentDownloadUtility(context) {
                    this._context = context;
                }
                AttachmentDownloadUtility.prototype.fileDownloadBase = function (attachmentId, entityName) {
                    var _this = this;
                    this._context.webAPI.retrieveRecord(entityName, attachmentId).then(function (attachment) { return _this.downloadAttachment(_this._context, attachment); }, function (error) { return _this.actionFailedCallback(_this._context, error); });
                };
                AttachmentDownloadUtility.prototype.downloadAttachment = function (_context, attachment) {
                    _context.navigation.openFile(this.getFile(attachment), this.getSaveMode());
                };
                AttachmentDownloadUtility.prototype.getFile = function (attachment) {
                    var AttachmentFileContent = "";
                    if (attachment.hasOwnProperty("body")) {
                        AttachmentFileContent = "body";
                    }
                    else if (attachment.hasOwnProperty("documentbody")) {
                        AttachmentFileContent = "documentbody";
                    }
                    if (attachment[Controls.AttachmentMimeType] == null) {
                        attachment[Controls.AttachmentMimeType] = "text/plain";
                    }
                    return {
                        fileName: attachment[Controls.AttachmentFileName],
                        mimeType: attachment[Controls.AttachmentMimeType],
                        fileContent: attachment[AttachmentFileContent],
                        fileSize: attachment[AttachmentFileContent].length
                    };
                };
                AttachmentDownloadUtility.prototype.getSaveMode = function () {
                    return {
                        openMode: Controls.OpenFileSaveMode
                    };
                };
                AttachmentDownloadUtility.prototype.actionFailedCallback = function (_context, error) {
                    Xrm.Navigation.openAlertDialog(error);
                };
                return AttachmentDownloadUtility;
            }());
            Controls.AttachmentDownloadUtility = AttachmentDownloadUtility;
            ;
            /**
             * Handles the css styling for control
             */
            var AttachmentControlStyles = (function () {
                function AttachmentControlStyles(context) {
                    this._context = context;
                }
                /**
                 * Handles the styling of control's elements
                 * @param itemName : name of control's element
                 */
                AttachmentControlStyles.prototype.getCssStyle = function (itemName) {
                    var styling;
                    switch (itemName) {
                        case StyleItemsName.FONTICON:
                            styling = {
                                cursor: "default",
                                fontSize: "16px",
                                paddingTop: '2px',
                                margin: '0 !important'
                            };
                            break;
                        case StyleItemsName.ACTIONABLE_FONT_ICON:
                            styling = {
                                cursor: "pointer",
                                fontSize: "16px",
                                paddingTop: '2px',
                                margin: '0 !important'
                            };
                            break;
                        case StyleItemsName.FILELABEL:
                            styling = {
                                color: this._context.theming.colors.linkcolor.normal,
                                paddingLeft: '10px',
                                paddingRight: '10px',
                                maxWidth: '50%',
                                overflow: 'hidden',
                                textOverflow: 'ellipsis',
                                whiteSpace: 'nowrap'
                            };
                            break;
                        case StyleItemsName.FILECONTAINER:
                            styling = {
                                width: "100%",
                                top: "0px",
                            };
                            break;
                        default:
                            styling = {};
                            break;
                    }
                    return styling;
                };
                return AttachmentControlStyles;
            }());
            Controls.AttachmentControlStyles = AttachmentControlStyles;
            ;
            var StyleItemsName = (function () {
                function StyleItemsName() {
                }
                return StyleItemsName;
            }());
            StyleItemsName.FONTICON = "FONTICON";
            StyleItemsName.ACTIONABLE_FONT_ICON = "ACTIONABLE_FONT_ICON";
            StyleItemsName.FILELABEL = "FILELABEL";
            StyleItemsName.FILESIZE = "FILESIZE";
            StyleItemsName.FILECONTAINER = "FILECONTAINER";
            Controls.StyleItemsName = StyleItemsName;
            ;
        })(Controls = USD.Controls || (USD.Controls = {}));
    })(USD = MscrmControls.USD || (MscrmControls.USD = {}));
})(MscrmControls || (MscrmControls = {}));
//# sourceMappingURL=FilePicker.js.map